#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-rename-plugin
version:              2.2.0.0
visibility:           public
id:                   hls-rename-plugin-2.2.0.0-9Dr8OXOR3Ec91e8wtOqAUz
key:                  hls-rename-plugin-2.2.0.0-9Dr8OXOR3Ec91e8wtOqAUz
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  804f5ba6fad332fa6d043881cfbe3e14
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-2.2.0.0-9Dr8OXOR3Ec91e8wtOqAUz
depends:
    base-4.18.2.1 containers-0.6.7 extra-1.7.16-6e0wBrlA2xu66mkOtGwbe0
    ghc-9.6.6 ghc-exactprint-1.7.1.0-3WI6pdPejDQOt9Crcgo5G
    ghcide-2.2.0.0-KYWvlbTD7z45Iv81bcdI4A
    hashable-1.4.7.0-LE3bCdm1Wgy6IgVYkRoAlQ
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-8qFqqPGEVaMJvvvBqZwbN7
    hls-plugin-api-2.2.0.0-8OOoB6gEqmT4UEewr4ZH15
    hls-refactor-plugin-2.2.0.0-JZQZgHisZ5jDLE5pblcP2z
    lens-5.3.3-Ag3JywAjDxJ2k98xBhf4hs lsp-2.2.0.0-1wTjR6m8XHMB9d0XTUKi2
    lsp-types-2.0.2.0-dUFitFTJB7FQc8xMsVNi8
    mod-0.2.1.0-CZuF1hauEYq9XbagZNZcFQ mtl-2.3.1
    syb-0.7.3-HezvxMxFoxE4YYIFSuLToH text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-I6eyTXb69D2BhxejMtPouo

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

